@@ -1,15 +1,12 @@
 library(testthat)
 context("sp From Table")
-testthat::skip_if_not(requireNamespace("maptools"))
-
-library(maptools)
 
 library(spbabel)
 data(mpoint1)
 ## generate all topology types
-data(wrld_simpl)
-poly1 <- wrld_simpl
-line1 <- as(wrld_simpl, "SpatialLinesDataFrame")
+
+poly1 <- .wrld_simpl
+line1 <- as(.wrld_simpl, "SpatialLinesDataFrame")
 point1 <- as(line1, "SpatialPointsDataFrame")
 
 ## create sptable versions
